use warnings;
use strict;

package Geo::EOP::Util;
use base 'Exporter';

our @gml311    = qw/NS_GML NS_GML_311 NS_XLINK_1999/;
our @hmas      = qw/NS_ATM_ESA NS_OHR_ESA NS_SAR_ESA NS_HMA_ESA/;
our @eops      = qw/NS_ATM_ESA NS_OPT_ESA NS_SAR_ESA NS_EOP_ESA/;

our @EXPORT    = (@gml311, @hmas, @eops);

our @EXPORT_TAGS =
 ( hma10     => [ @gml311, @hmas ]
 , eop11     => [ @gml311, @eops ]
 , eop12beta => [ @gml311, @eops ]
 );

=chapter NAME
Geo::EOP::Util - EOP useful constants

=chapter SYNOPSIS

  use Geo::EOP::Util ':eop11';

=chapter DESCRIPTION
Defines the namespaces used with EOP.

=chapter FUNCTIONS

=section Constants

All export tags defined NS_ATM_ESA, NS_SAR_ESA for EOP/HMA.
Besides, for convenience NS_GML_311 and NS_XLINK_1999 (which are defined
in M<Geo::GML::Util>) are exported as well.

The constants have names which end with C<_ESA>, because I expect them
to move to the opengis name-space in the forseeable future.  Those new
names will not have the shorter constant name.

=subsection :hma10
Exports NS_OHR_ESA and NS_HMA_ESA as well.

=subsection :eop11
Exports NS_OPT_ESA and NS_EOP_ESA as well.

=subsection :eop12beta
Same exports as C<:eop11>

=cut

use constant NS_ATM_ESA => 'http://earth.esa.int/atm';
use constant NS_SAR_ESA => 'http://earth.esa.int/sar';

use constant NS_GML     => 'http://www.opengis.net/gml';
use constant NS_GML_311 => NS_GML;
use constant NS_XLINK_1999 => 'http://www.w3.org/1999/xlink';

# HMA before renaming
use constant NS_OHR_ESA => 'http://earth.esa.int/ohr';
use constant NS_HMA_ESA => 'http://earth.esa.int/hma';

# EOP renaming
use constant NS_OPT_ESA => 'http://earth.esa.int/opt';
use constant NS_EOP_ESA => 'http://earth.esa.int/eop';

1;
